/***************/
/* pcbplot.cpp */
/***************/

#include "fctsys.h"
#include "common.h"

#include "gerbview.h"
#include "pcbplot.h"


/* The group of plot options - sadly global XXX */
PCB_Plot_Options g_pcb_plot_options;


/**************************************************************/
/* void PCB_BASE_FRAME::ToPlotter(wxCommandEvent& event) */
/***************************************************************/

/** TODO */
void GERBVIEW_FRAME::ToPlotter(wxCommandEvent& event)
{
}

